@@ -3,22 +3,25 @@ use v6;
 use PDF:ver(v0.3.2+);
 
 #| PDF entry-point. either a trailer dict or an XRef stream
-class PDF::Class:ver<0.2.9> #:api<PDF-1.7>
+class PDF::Class:ver<0.3.0>#:api<PDF-1.7>
     is PDF {
-
+    # See [PDF 32000 Table 15 - Entries in the file trailer dictionary]
     # base class declares: $.Size, $.Encrypt, $.ID
+    ## use ISO_32000::File_trailer;
+    ## also does ISO_32000::File_trailer;
+
     use PDF::COS::Tie;
     use PDF::Class::Type;
     use PDF::Info;
-    has PDF::Info $.Info is entry(:indirect);  #| (Optional; must be an indirect reference) The document’s information dictionary
-    my subset Catalog of PDF::Class::Type where { .type eq 'Catalog' };  # autoloaded PDF::Catalog
+    has PDF::Info $.Info is entry(:indirect);  # (Optional; must be an indirect reference) The document’s information dictionary
+    my subset Catalog of PDF::Class::Type where { .<Type> ~~ 'Catalog' };  # autoloaded PDF::Catalog
     has Catalog $.Root is entry(:required, :indirect, :alias<catalog>);
 
     method type { 'PDF' }
     method version is rw {
         Proxy.new(
             FETCH => {
-                Version.new: $.catalog<Version> // self.reader.?version // '1.4'
+                Version.new: $.catalog<Version> // self.?reader.?version // '1.4'
             },
             STORE => -> $, Version $_ {
                 my $name = .Str;
