@@ -10,10 +10,12 @@ role PDF::Field::Text
     use PDF::COS::Stream;
     use PDF::COS::TextString;
 
-    # [PDF 1.7 TABLE 8.78 Additional entry specific to a text field]
+    # See [PDF 32000 TABLE 229 - Additional entry specific to a text field]
+    ## use ISO_32000::Text_field_additional;
+    ## also does ISO_32000::Text_field_additional;
     my subset TextOrStream of PDF::COS where PDF::COS::Stream | PDF::COS::TextString;
-    multi sub coerce(Str $s is rw, TextOrStream) {
-	PDF::COS.coerce($s, PDF::COS::TextString)
+    multi sub coerce(Str $_ is rw, TextOrStream) {
+	PDF::COS.coerce($_, PDF::COS::TextString)
     }
     multi sub coerce($_, TextOrStream) is default {
 	fail "unable to coerce {.perl} to Text or a Stream";
@@ -21,5 +23,5 @@ role PDF::Field::Text
     has TextOrStream $.V is entry(:&coerce, :inherit, :alias<value>);
     has TextOrStream $.DV is entry(:&coerce, :inherit, :alias<default-value>);
 
-    has UInt $.MaxLen is entry; #| (Optional; inheritable) The maximum length of the field’s text, in characters.
+    has UInt $.MaxLen is entry; # (Optional; inheritable) The maximum length of the field’s text, in characters.
 }
