@@ -8,9 +8,12 @@ class PDF::Group
     is PDF::COS::Dict
     does PDF::Class::Type['Type','S'] {
 
-    # see [Table 96 – Entries Common to all Group Attributes Dictionaries]
+    # see [PDF 32000 Table 96 – Entries Common to all Group Attributes Dictionaries]
+    ## use ISO_32000::Group_Attributes_common;
+    ## also does ISO_32000::Group_Attributes_common;
     use PDF::COS::Tie;
     use PDF::COS::Name;
 
     has PDF::COS::Name $.Type is entry where 'Group';
+    has PDF::COS::Name $.S is entry;
 }
